@@ -64,7 +64,9 @@ static void eog_job_transform_run (EogJob *ejob);
 
 static void eog_job_init (EogJob *job)
 {
-	job->mutex = g_mutex_new();
+	/* NOTE: We need to allocate the mutex here so the ABI stays the same when it used to use g_mutex_new */
+	job->mutex = g_malloc (sizeof (GMutex));
+	g_mutex_init (job->mutex);
 	job->progress = 0.0;
 }
 
@@ -81,8 +83,8 @@ eog_job_dispose (GObject *object)
 	}
 
 	if (job->mutex) {
-		g_mutex_free (job->mutex);
-		job->mutex = NULL;
+		g_mutex_clear (job->mutex);
+		g_free (job->mutex);
 	}
 
 	(* G_OBJECT_CLASS (eog_job_parent_class)->dispose) (object);
@@ -609,10 +611,26 @@ eog_job_save_run (EogJob *ejob)
 		eog_image_data_ref (image);
 
 		if (!eog_image_has_data (image, EOG_IMAGE_DATA_ALL)) {
-			eog_image_load (image,
-					EOG_IMAGE_DATA_ALL,
-					NULL,
-					&ejob->error);
+			EogImageMetadataStatus m_status;
+			gint data2load = 0;
+
+			m_status = eog_image_get_metadata_status (image);
+			if (!eog_image_has_data (image, EOG_IMAGE_DATA_IMAGE)) {
+				// Queue full read in this case
+				data2load = EOG_IMAGE_DATA_ALL;
+			} else if (m_status == EOG_IMAGE_METADATA_NOT_READ)
+			{
+				// Load only if we haven't read it yet
+				data2load = EOG_IMAGE_DATA_EXIF
+						| EOG_IMAGE_DATA_XMP;
+			}
+
+			if (data2load != 0) {
+				eog_image_load (image,
+						data2load,
+						NULL,
+						&ejob->error);
+			}
 		}
 
 		handler_id = g_signal_connect (G_OBJECT (image),
@@ -690,9 +708,6 @@ eog_job_save_as_run (EogJob *ejob)
 	EogJobSaveAs *saveas_job;
 	GList *it;
 	guint n_images;
-	guint file_permissions = 00000;
-	guint permissions_mask = 00600;
-	GFileInfo *info;
 
 	g_return_if_fail (EOG_IS_JOB_SAVE_AS (ejob));
 
@@ -716,12 +731,29 @@ eog_job_save_as_run (EogJob *ejob)
 		eog_image_data_ref (image);
 
 		if (!eog_image_has_data (image, EOG_IMAGE_DATA_ALL)) {
-			eog_image_load (image,
-					EOG_IMAGE_DATA_ALL,
-					NULL,
-					&ejob->error);
+			EogImageMetadataStatus m_status;
+			gint data2load = 0;
+
+			m_status = eog_image_get_metadata_status (image);
+			if (!eog_image_has_data (image, EOG_IMAGE_DATA_IMAGE)) {
+				// Queue full read in this case
+				data2load = EOG_IMAGE_DATA_ALL;
+			} else if (m_status == EOG_IMAGE_METADATA_NOT_READ)
+			{
+				// Load only if we haven't read it yet
+				data2load = EOG_IMAGE_DATA_EXIF
+						| EOG_IMAGE_DATA_XMP;
+			}
+
+			if (data2load != 0) {
+				eog_image_load (image,
+						data2load,
+						NULL,
+						&ejob->error);
+			}
 		}
 
+
 		g_assert (ejob->error == NULL);
 
 		handler_id = g_signal_connect (G_OBJECT (image),
@@ -764,27 +796,6 @@ eog_job_save_as_run (EogJob *ejob)
 						     dest_info,
 						     &ejob->error);
 
-		/* get file permissions */
-		info = g_file_query_info (saveas_job->file,
-					  G_FILE_ATTRIBUTE_UNIX_MODE,
-					  G_FILE_QUERY_INFO_NONE,
-					  NULL,
-					  NULL);
-
-		file_permissions = g_file_info_get_attribute_uint32 (info, G_FILE_ATTRIBUTE_UNIX_MODE);
-
-		/* apply permission mask to file permissions */
-		file_permissions |= permissions_mask;
-
-		g_file_set_attribute_uint32 (saveas_job->file,
-					     G_FILE_ATTRIBUTE_UNIX_MODE,
-					     file_permissions,
-					     G_FILE_QUERY_INFO_NONE,
-					     NULL,
-					     NULL);
-
-		g_object_unref (info);
-
 		if (src_info)
 			g_object_unref (src_info);
 
